@@ -1,22 +1,17 @@
-package # hide from PAUSE
-    DBIx::Class::CDBICompat::AttributeAPI;
-
-use strict;
-use warnings;
-
-use base 'DBIx::Class';
+package DBIx::Class::CDBICompat::AttributeAPI;
 
 sub _attrs {
   my ($self, @atts) = @_;
   return @{$self->{_column_data}}{@atts};
 }
 
-sub _attr { shift->_attrs(@_) }
+*_attr = \&_attrs;
 
 sub _attribute_store {
   my $self   = shift;
   my $vals   = @_ == 1 ? shift: {@_};
-  $self->store_column($_, $vals->{$_}) for keys %{$vals};
+  my (@cols) = keys %$vals;
+  @{$self->{_column_data}}{@cols} = @{$vals}{@cols};
 }
 
 sub _attribute_set {
@@ -32,7 +27,7 @@ sub _attribute_delete {
 
 sub _attribute_exists {
   my ($self, $attr) = @_;
-  $self->has_column_loaded($attr);
+  exists $self->{_column_data}{$attr};
 }
 
 1;
