@@ -1,16 +1,15 @@
-package # hide from PAUSE
-    DBIx::Class::CDBICompat::AutoUpdate;
+package DBIx::Class::CDBICompat::AutoUpdate;
 
 use strict;
 use warnings;
 
-use base 'DBIx::Class';
+use base qw/Class::Data::Inheritable/;
 
-__PACKAGE__->mk_group_accessors( inherited => '__AutoCommit' );
+__PACKAGE__->mk_classdata('__AutoCommit');
 
 sub set_column {
   my $self = shift;
-  my $ret = $self->next::method(@_);
+  my $ret = $self->NEXT::set_column(@_);
   $self->update if ($self->autoupdate && $self->{_in_storage});
   return $ret;
 }
