@@ -4,10 +4,10 @@ use strict;
 use warnings FATAL => 'all';
 
 sub retrieve          { shift->find(@_)            }
-sub retrieve_all      { shift->search_literal('1', @_) }
+sub retrieve_all      { shift->search              }
 sub retrieve_from_sql { shift->search_literal(@_)  }
 
-sub count_all          { shift->count_literal('1')  }
+sub count_all         { shift->count               }
   # Contributed by Numa. No test for this though.
 
 1;
