@@ -1,20 +1,13 @@
-package # hide from PAUSE
-    DBIx::Class::CDBICompat::Triggers;
+package DBIx::Class::CDBICompat::Triggers;
 
 use strict;
 use warnings;
-
-use base 'DBIx::Class';
-
 use Class::Trigger;
 
 sub insert {
   my $self = shift;
-
-  return $self->create(@_) unless ref $self;
-
   $self->call_trigger('before_create');
-  $self->next::method(@_);
+  $self->NEXT::ACTUAL::insert(@_);
   $self->call_trigger('after_create');
   return $self;
 }
@@ -24,7 +17,7 @@ sub update {
   $self->call_trigger('before_update');
   my @to_update = keys %{$self->{_dirty_columns} || {}};
   return -1 unless @to_update;
-  $self->next::method(@_);
+  $self->NEXT::ACTUAL::update(@_);
   $self->call_trigger('after_update');
   return $self;
 }
@@ -32,7 +25,7 @@ sub update {
 sub delete {
   my $self = shift;
   $self->call_trigger('before_delete') if ref $self;
-  $self->next::method(@_);
+  $self->NEXT::ACTUAL::delete(@_);
   $self->call_trigger('after_delete') if ref $self;
   return $self;
 }
@@ -41,7 +34,7 @@ sub store_column {
   my ($self, $column, $value, @rest) = @_;
   my $vals = { $column => $value };
   $self->call_trigger("before_set_${column}", $value, $vals);
-  return $self->next::method($column, $vals->{$column});
+  return $self->NEXT::ACTUAL::store_column($column, $vals->{$column});
 }
 
 1;
