@@ -33,7 +33,7 @@ sub new {
   if ($attrs) {
     $new->throw("attrs must be a hashref" ) unless ref($attrs) eq 'HASH';
     while (my ($k, $v) = each %{$attrs}) {
-      $new->store_column($k => $v);
+      $new->store_column($k => $v) if exists $class->_columns->{$k};
     }
   }
   return $new;
@@ -176,6 +176,19 @@ sub get_column {
   return undef;
 }
 
+=item get_columns
+
+  my %data = $obj->get_columns;
+
+Fetch all column values at once.
+
+=cut
+
+sub get_columns {
+  my $self = shift;
+  return map { $_ => $self->get_column($_) } $self->columns;
+}
+
 =item set_column
 
   $obj->set_column($col => $val);
@@ -194,6 +207,29 @@ sub set_column {
   return $ret;
 }
 
+=item set_columns
+
+  my $copy = $orig->set_columns({ $col => $val, ... });
+
+Set more than one column value at once.
+
+=cut
+
+sub set_columns {
+  my ($self,$data) = @_;
+  while (my ($col,$val) = each %$data) {
+    $self->set_column($col,$val);
+  }
+}
+
+=item copy
+
+  my $copy = $orig->copy({ change => $to, ... });
+
+Insert a new row with the specified changes.
+
+=cut
+
 =item store_column
 
   $obj->store_column($col => $val);
@@ -220,12 +256,6 @@ sub _row_to_object {
   return $new;
 }
 
-=item copy
-
-  my $copy = $orig->copy({ change => $to, ... });
-
-=cut
-
 sub copy {
   my ($self, $changes) = @_;
   my $new = bless({ _column_data => { %{$self->{_column_data}}} }, ref $self);
