@@ -1,5 +1,4 @@
-package # hide from PAUSE 
-    ActorAlias;
+package ActorAlias;
 
 BEGIN { unshift @INC, './t/testlib'; }
 
