@@ -1,10 +1,7 @@
-package # hide from PAUSE
-    MyBase;
+package MyBase;
 
 use strict;
-use base qw(DBIx::Class::CDBICompat);
-
-use DBI;
+use base qw(DBIx::Class);
 
 use vars qw/$dbh/;
 
